
## CATO-CLI - mutation.sites.removeSite:
[Click here](https://api.catonetworks.com/documentation/#mutation-removeSite) for documentation on this operation.

### Usage for mutation.sites.removeSite:

`catocli mutation sites removeSite -h`

`catocli mutation sites removeSite <accountID> <json>`

`catocli mutation sites removeSite 12345 "$(cat < removeSite.json)"`

`catocli mutation sites removeSite 12345 '{"siteId": "ID"}'`

#### Operation Arguments for mutation.sites.removeSite ####
`accountId` [ID] - (required) N/A 
`siteId` [ID] - (required) N/A 
